import {LogBox, SafeAreaView, StyleSheet, Text, View} from 'react-native';
import {I18nextProvider, useTranslation} from "react-i18next";
import i18n from "./translation/i18n"; // Importez l'instance déjà initialisée
import { SafeAreaProvider } from "react-native-safe-area-context";
import StackNavigator from "./routes/StackNavigator";
import { useEffect } from 'react';
import * as SplashScreen from 'expo-splash-screen';
import {QueryClient, QueryClientProvider} from "@tanstack/react-query";
const queryClient = new QueryClient();

export default function App() {
    // LogBox.ignoreAllLogs(true);
    useEffect(() => {
      async function prepare() {
        try {
          await SplashScreen.preventAutoHideAsync(); // affichage
          
          // Chargement des fonts, appels API externes, etc...
          
          // On fait une pause 2 sec pour simuler un chargement lent
          await new Promise(resolve => setTimeout(resolve, 2000));
  
        } catch (e) { console.warn(e); } finally {
          await SplashScreen.hideAsync(); // masquage
        }
      } prepare(); }, []);


  const { t } = useTranslation();
  return (
    <QueryClientProvider client={queryClient}>
      <SafeAreaProvider>
          <I18nextProvider i18n={i18n}>
              <StackNavigator/>
          </I18nextProvider>
      </SafeAreaProvider>
    </QueryClientProvider>
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#fff',
    alignItems: 'center',
    justifyContent: 'center',
  },
});
