import { Modal, View, Text, TextInput, StyleSheet } from "react-native";
import WhiteButton from "../buttons/WhiteButton";
import BlueButton from "../buttons/BlueButton";
import { useState } from "react";

interface Props {
    showModal: boolean;
    onClosePressed: () => void;
    onPlayPressed: (nbPlayer: number) => void;
}

export default function ModalCreateLobby({showModal, onClosePressed, onPlayPressed}: Props) {
    const [nbPlayer, setNbPlayer] = useState<number>(1);
    return (
        <Modal visible={showModal} animationType="slide" transparent={true}>
            <View style={styles.centeredView}>
                <View style={styles.modalView}>
                    <Text style={styles.title}>CREATE A LOBBY</Text>
                    <View style={styles.inputGroup}>
                        <Text>NUMBER OF PLAYER</Text>
                        <TextInput style={styles.input} defaultValue={nbPlayer.toString()} onChangeText={(text) => setNbPlayer(Number(text))}/>
                    </View>
                    <View style={styles.buttonGroup}>
                        <View style={styles.button}>
                            <WhiteButton text="CLOSE" onPress={onClosePressed} isDisabled={false}/>
                        </View>   
                        <View style={styles.button}>
                            <BlueButton text="PLAY" onPress={() => onPlayPressed(nbPlayer)} isDisabled={false}/>
                        </View>
                    </View>
                </View>
            </View>
        </Modal>
    );
}

const styles = StyleSheet.create({
    centeredView: {
        flex: 1,
        justifyContent: 'center',
        alignItems: 'center',
        backgroundColor: 'rgba(0, 0, 0, 0.5)'
    },
    modalView: {
        display: 'flex',
        justifyContent: 'space-between',
        height: 400,
        width: '90%',
        margin: '10%',
        padding: '5%',
        backgroundColor: 'white',
        borderRadius: 20,
        alignItems: 'center',
        shadowColor: '#000',
        shadowOffset: {
            width: 0,
            height: 2,
        },
        shadowOpacity: 0.25,
        shadowRadius: 4,
        elevation: 5,
    },
    buttonGroup: {
        flexDirection: 'row',
        justifyContent: 'space-between',
        width: '100%',
    },
    button: {
        width: '45%',
    },
    title: {
        fontSize: 40,
        fontWeight: "bold",
        color: "#00b3f4",
        marginBottom: 10,
        alignSelf: "center", // Centre uniquement le titre
        textAlign: 'center',
    },
    inputGroup: {
        width: '100%',
        marginBottom: 20,
    },
    input: {
        width: "100%",
        height: 70,
        backgroundColor: "white",
        borderColor: "#2ec7ff",
        borderWidth: 3,
        borderRadius: 8,
        paddingLeft: 10,
        elevation: 5,
        shadowColor: "#000",
        shadowOffset: { width: 0, height: 4 },
        shadowOpacity: 0.25,
        shadowRadius: 3.84,
    },
});