import { View, StyleSheet, Text } from "react-native";
import { SelectList } from "react-native-dropdown-select-list";
import React from "react";
import { Category } from "../../models/Quiz";

interface Props {
    data: Category[], // La liste des catégories
    setSelected: (val: Category) => void, // Fonction pour gérer la sélection d'une catégorie
    title: string, // Titre affiché au-dessus de la liste
}

export default function SelectListBoxCategory({ data, setSelected, title }: Props) {
    // Transformer les données dans le format attendu
    const transformedData = data.map((category) => ({
        key: category.id.toString(), // Sauvegarde l'ID en tant que clé
        value: category.name, // Affiche le nom
    }));

    return (
        <View style={styles.container}>
            <View style={styles.dropdownContainer}>
                <Text style={styles.title}>{title}</Text>
                <SelectList
                    setSelected={(key: string) => {
                        // Trouver la catégorie sélectionnée à partir de son ID
                        const selectedCategory = data.find((category) => category.id.toString() === key);
                        if (selectedCategory) {
                            setSelected(selectedCategory);
                        }
                    }}
                    data={transformedData} // Données transformées pour SelectList
                    save="key" // Sauvegarde la clé (ID)
                    dropdownStyles={styles.dropdownStyles}
                    boxStyles={styles.boxStyles}
                    inputStyles={styles.inputStyles}
                />
            </View>
        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        alignItems: "center",
        width: "100%",
    },
    dropdownContainer: {
        width: "100%",
    },
    title: {
        fontSize: 20,
        fontWeight: "bold",
        marginBottom: 5,
        color: "#333",
        textAlign: "left",
    },
    dropdownStyles: {
        position: "absolute",
        width: "100%",
        top: 40,
        zIndex: 2,
        backgroundColor: "white",
        borderColor: "black",
        borderWidth: 1,
        borderRadius: 8,
    },
    boxStyles: {
        backgroundColor: "white",
        borderColor: "#bebebe",
        borderWidth: 2,
        borderRadius: 8,
        height: 70,
        alignItems: "center",
        elevation: 5,
        shadowColor: "#000",
        shadowOffset: { width: 0, height: 4 },
        shadowOpacity: 0.25,
        shadowRadius: 3.84,
    },
    inputStyles: {
        fontSize: 18,
        color: "black",
    },
});
