import { View, Text, StyleSheet, TouchableOpacity } from "react-native";
import { SelectModeType } from "../../models/SelectModeType";

interface Props {
    mode: SelectModeType;
    setMode: (mode: SelectModeType) => void;
}

export default function SelectMode({ mode, setMode }: Props) {
    return (
        <View style={styles.container}>
            <View style={styles.buttonContainer}>
                <TouchableOpacity onPress={() => setMode("play")} style={{marginLeft: '10%'}}>
                    <Text style={[styles.text, mode === "play" && styles.activeText]}>Play a quiz</Text>
                </TouchableOpacity>
                <View style={[styles.bar, mode === "play" ? styles.activeBar : styles.inactiveBar]} />
            </View>

            <View style={styles.buttonContainer}>
                <TouchableOpacity onPress={() => setMode("join")} style={{marginRight: '10%'}}>
                    <Text style={[styles.text, mode === "join" && styles.activeText]}>Join a quiz</Text>
                </TouchableOpacity>
                <View style={[styles.bar, mode === "join" ? styles.activeBar : styles.inactiveBar]} />
            </View>

        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        display: 'flex',
        width: '100%',
        height: '10%',
        flexDirection: 'row',
        backgroundColor: '#f3f3f3',
        borderRadius: 10,
        justifyContent: 'space-around',
        alignItems: 'center',
        // Ombre pour Android
        elevation: 5,
        // Ombre pour iOS
        shadowColor: '#000',
        shadowOffset: { width: 0, height: 4 }, // Décalage de l'ombre en bas
        shadowOpacity: 0.25, // Opacité de l'ombre
        shadowRadius: 3.84, // Flou de l'ombre
    },
    buttonContainer: {
        display: 'flex',
        flexDirection: 'column',
        width: '40%',
        alignItems: 'center',
        gap: "5%",
    },
    text: {
        fontSize: 25,
        color: '#bebebe',
    },
    activeText: {
        color: '#2ec7ff',
    },
    bar: {
        width: '100%',
        height: 4,
        marginTop: 4,
        borderRadius: 10,
    },
    activeBar: {
        backgroundColor: '#2ec7ff', // Couleur pour le bouton actif
    },
    inactiveBar: {
        backgroundColor: '#bebebe', // Couleur grise pour les boutons inactifs
    },
});
