import { View, Text, StyleSheet, Image } from "react-native";
import {User} from "../../../models/User";

interface Props {
    user: User;
    score: number;
    maxScore: number;
    isFirst: boolean;
}

export default function UserScore({ user, score, maxScore, isFirst }: Props) {

    function shortenString(input: string): string {
        if (input.length <= 5) {
            return input; // Si la chaîne est déjà de 4 caractères ou moins, on la retourne telle quelle
        }
        return `${input.slice(0, 5)}...`; // Garde les 4 premiers caractères et ajoute "..."
    }

    return (
        <View style={styles.container}>
            <View style={[styles.avatarContainer, isFirst && styles.firstAvatar]}>
                <Image
                    source={require('../../../assets/ProfilBaseImage.png')} // URL de l'avatar ou placeholder
                    style={styles.avatar}
                />
            </View>
            <Text style={styles.userName}>{shortenString(user.username.toUpperCase())}</Text>
            <Text style={styles.userScore}>
                {score}/{maxScore}
            </Text>
        </View>
    );
}



const styles = StyleSheet.create({
    container: {
        display: "flex",
        flexDirection: "column",
        alignItems: "center",
        justifyContent: "space-around",
        marginHorizontal: 10,
    },
    avatarContainer: {
        width: 70,
        height: 70,
        borderRadius: 50,
        backgroundColor: "#d9e3f0", // Fond gris clair
        alignItems: "center",
        justifyContent: "center",
    },
    firstAvatar: {
        width: 90,
        height: 90,
        // borderWidth: 3, // Ajoute une bordure pour le premier utilisateur
        // borderColor: "#FFD700", // Couleur or pour marquer le premier
    },
    avatar: {
        width: "100%",
        height: "100%",
        resizeMode: "cover",
    },
    userName: {
        fontSize: 16,
        fontWeight: "bold",
        color: "#000",
        marginTop: 5,
        textAlign: "center",
    },
    userScore: {
        fontSize: 14,
        fontWeight: "500",
        color: "#333",
        textAlign: "center",
        marginTop: 5,
    },
});
