import { View, StyleSheet, Image, TouchableOpacity } from "react-native";
import { NavigationProp } from "@react-navigation/native";
import ConfirmModal from "../PlayingQuiz/ComfirmModal";

interface Props {
    navigation: NavigationProp<any>;
    buttonGoBack: boolean
}

/**
 * HeaderNavigation : Header qui permet de remonter à l'écran précédent
 * @param navigation - navigation
 * @param buttonGoBack - boolean qui dit si le bouton de retour doit être affiché
 */
export default function HeaderNavigation({ navigation, buttonGoBack }: Props) {
    return (
        <View style={styles.container}>
            {buttonGoBack && ( // Affiche le bouton uniquement si buttonGoBack est true
                <TouchableOpacity onPress={() => navigation.goBack()} style={styles.goBackContainer}>
                    <Image source={require('../../assets/GoBackNavigation.png')} />
                </TouchableOpacity>
            )}
            <Image source={require('../../assets/TitleApp.png')} style={styles.titleImage} />
        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        flexDirection: 'row', // Alignement en ligne
        alignItems: 'center', // Centrer les éléments verticalement
        justifyContent: 'center', // Centrer les éléments horizontalement
        width: '100%',
        height: 60, // Ajustez en fonction de votre design
        position: 'relative', // Pour positionner l'élément de gauche
    },
    goBackContainer: {
        position: 'absolute', // Place l'élément indépendamment
        left: 10, // Décalé à gauche
    },
    titleImage: {
        width: 170, // Ajustez en fonction de la taille de l'image
        height: 80,
        resizeMode: 'contain', // Pour conserver les proportions
    },
});
