import React from "react";
import { View, StyleSheet } from "react-native";
import * as Progress from "react-native-progress";

interface Props {
    progress: number; // Valeur entre 0 et 1 représentant la progression
}

export default function ProgressBar({ progress }: Props) {
    // Limite la progression entre 0 et 1
    const clampedProgress = Math.min(Math.max(progress, 0), 1);

    // Calcul de la couleur en fonction de la progression
    const interpolateColor = () => {
        const startColor = { r: 43, g: 115, b: 254 }; // #45128C (bleu-violet)
        const endColor = { r: 255, g: 0, b: 0 }; // Rouge

        const r = Math.floor(startColor.r + (endColor.r - startColor.r) * clampedProgress);
        const g = Math.floor(startColor.g + (endColor.g - startColor.g) * clampedProgress);
        const b = Math.floor(startColor.b + (endColor.b - startColor.b) * clampedProgress);

        return `rgb(${r}, ${g}, ${b})`;
    };

    return (
        <View style={styles.container}>
            <Progress.Bar
                progress={clampedProgress}
                width={null} // Occupe toute la largeur disponible
                height={25} // Épaisseur de la barre
                color={interpolateColor()} // Couleur dynamique
                borderRadius={15} // Bords arrondis
                unfilledColor="#e0e0e0" // Couleur de fond
                borderWidth={0} // Supprime la bordure
            />
        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        width: "100%",
        padding: 10, // Ajoute un espace autour de la barre
    },
});
