import { useState, useEffect, useCallback } from 'react';
import AsyncStorage from '@react-native-async-storage/async-storage';

const useCookie = (cookieName: string) => {
    const [error, setError] = useState<Error | null>(null);

    // Fonction pour sauvegarder le cookie
    const saveCookie = useCallback(async (value: string, expirationInDays = 7) => {
        try {
            await AsyncStorage.setItem(cookieName, value);
            setError(null);
        } catch (e) {
            if(e instanceof Error) {
                setError(e);
            }
            setError(new Error('An error occurred while saving the cookie'));
        }
    }, [cookieName]);

    // Fonction pour supprimer le cookie
    const removeCookie = useCallback(async () => {
        try {
            await AsyncStorage.removeItem(cookieName);
            setError(null);
        } catch (e) {
            if(e instanceof Error) {
                setError(e);
            }
            setError(new Error('An error occurred while removing the cookie'));
        }
    }, [cookieName]);

    const getCookie = useCallback(async () => {
        try {
            const value = await AsyncStorage.getItem(cookieName);
            setError(null);
            return value;
        } catch (e) {
            if(e instanceof Error) {
                setError(e);
            }
            setError(new Error('An error occurred while getting the cookie'));
        }
    }, [cookieName]);


    return {
        error,
        saveCookie,
        removeCookie,
        getCookie,
    };
};

export default useCookie;