import { Text,View, StyleSheet } from "react-native";
import SelectListBoxString from "../../../components/PlayQuiz/SelectListBoxString";
import React, {useEffect, useState} from "react";
import InputPlayQuiz from "../../../components/PlayQuiz/InputPlayQuiz";
import BlueButton from "../../../components/buttons/BlueButton";
import {useQuizService} from "../../../services/QuizService";
import {NavigationProp} from "@react-navigation/native";
import {Category} from "../../../models/Quiz";
import SelectListBoxCategory from "../../../components/PlayQuiz/SelectListBoxCategory";
import HttpError from "../../../services/HttpError";

const difficulty = [
    { key: "easy", value: "easy" },
    { key: "medium", value: "medium" },
    { key: "hard", value: "hard" },
];

interface Props {
    navigation: NavigationProp<any>;
}

export default function PlayQuizGenerateQuiz({navigation}: Props) {
    const [difficutlyChoose, setDifficutlyChoose] = React.useState("");
    const [nbQuestions, setNbQuestions] = React.useState("10");
    const [buttonIsDisabled, setButtonIsDisabled] = React.useState(true);
    const [categories, setCategories] = useState<Category[]>([]);
    const [categoryChoose, setCategoryChoose] = React.useState<Category | null>(null);

    const {generateQuiz, getCategories} = useQuizService();
    const fetchingCategories = async () => {
        const categories = await getCategories();
        let categoriesTemp: Category[] = [];
        categories.map((category: Category) => {
            categoriesTemp.push({'name': category.name, 'id': category.id});
        });
        setCategories(categoriesTemp);
    }

    useEffect(() => {
        fetchingCategories();
    }, []);

    useEffect(() => {
        if(nbQuestions === "" || difficutlyChoose === "" || categoryChoose === null)
        {
            setButtonIsDisabled(true);
        }
        else
        {
            setButtonIsDisabled(false);
        }

    }, [difficutlyChoose,categoryChoose,nbQuestions]);

    const handlePlayButtonPress = async () => {
        const quizGenerated = await generateQuiz(parseInt(nbQuestions), categoryChoose ? categoryChoose.id : 10 , difficutlyChoose);
        if(HttpError.isHttpError(quizGenerated)) {
            return;
        }
        navigation.reset({
            index: 0,
            routes: [
                {
                    name: "PlayingQuiz",
                    params: {runId: quizGenerated.id, quizId: quizGenerated.quizId},
                },
            ]
        });
    };

    return (
        <View style={styles.container}>
            <View style={styles.contentContainer}>
                <View style={styles.fieldContainer}>
                    <SelectListBoxString title="CHOOSE A DIFFICULTY" data={difficulty} setSelected={setDifficutlyChoose} />
                    <SelectListBoxCategory title="CHOOSE A CATEGORY" data={categories} setSelected={setCategoryChoose} />
                    <InputPlayQuiz title="CHOOSE A NUMBER OF QUESTIONS" setText={setNbQuestions} numeric={true} defaultValue={nbQuestions}/>
                </View>
                <View style={styles.buttonPlayContainer}>
                    <BlueButton onPress={handlePlayButtonPress} text={"PLAY"} isDisabled={buttonIsDisabled}/>
                </View>
            </View>
        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        display: "flex",
        width: "100%",
        height: "75%",
        justifyContent: "space-between",
    },
    contentContainer: {
        flex: 1, // Prend toute la hauteur disponible
        flexDirection: "column",
        justifyContent: "space-between",
    },
    fieldContainer: {
        width: "100%",
        flexDirection: "column",
        justifyContent: "space-between",
        marginTop: 20,
        gap: 20,
    },
    buttonPlayContainer: {
        alignItems: "center",
        paddingVertical: 20,
    },
});
