import { StyleSheet, View, Text } from "react-native";
import AboutAQuiz from "../../../components/PlayQuiz/AboutAQuiz";
import BlueButton from "../../../components/buttons/BlueButton";
import React, { useEffect } from "react";
import InputPlayQuiz from "../../../components/PlayQuiz/InputPlayQuiz";
import {Quiz} from "../../../models/Quiz";
import { useQuizService } from "../../../services/QuizService";
import HttpError from "../../../services/HttpError";
import {NavigationProp} from "@react-navigation/native";
import {RunInformations} from "../../../models/RunInformations";
import {QuizInformations} from "../../../models/QuizInformations";

interface Props {
    navigation: NavigationProp<any>;
}
export default function PlayQuizJoinQuiz({navigation}: Props) {
    const [codeQuiz, setCodeQuiz] = React.useState("");
    const [quiz, setQuiz] = React.useState<Quiz>();
    const [error, setError] = React.useState<string>("");
    const [runInformations, setRunInformations] = React.useState<RunInformations>();
    const [quizInformations, setQuizInformations] = React.useState<QuizInformations>();

    const { getRunsInfo, getQuizInformations } = useQuizService();

    useEffect(() => {
        fetchRuns();
    }, [codeQuiz]);

    const fetchRuns = async () => {

        if(codeQuiz === "") return;
        if(codeQuiz.length < 6 )
        {
            setError("A quiz contains 6 characters");
            return;
        }

        const runFetched = await getRunsInfo(codeQuiz);
        if (runFetched instanceof HttpError) {
            setError("The quiz does not exist");
            return;
        }
        const quizInformations = await getQuizInformations(runFetched.quizId);
        if (quizInformations instanceof HttpError) {
            setError("The quiz does not exist");
            return;
        }

        setError("");
        setQuizInformations(quizInformations);
        setRunInformations(runFetched);
    };

    const handlePlayButtonPress = () => {
        navigation.reset({
            index: 0,
            routes: [
                {
                    name: "PlayingQuiz",
                    params: {runId: runInformations?.id, quizId: runInformations?.quizId },
                },
            ]
        });
    };

    return (
        <View style={styles.container}>
            <View style={styles.contentContainer}>
                <View style={styles.fieldContainer}>
                    {error ? <Text style={styles.errorText}>{error}</Text> : null}
                    <InputPlayQuiz placeholder={"Enter quiz ID"} setText={setCodeQuiz} noTitle={true} />
                    <AboutAQuiz runInformations={runInformations} quizInformations={quizInformations} />
                </View>
                <View style={styles.buttonPlayContainer}>
                    <BlueButton onPress={handlePlayButtonPress} text={"PLAY"} isDisabled={codeQuiz==="" || error!==""}/>
                </View>
            </View>
        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        display: "flex",
        width: "100%",
        height: "75%",
        justifyContent: "space-between",
    },
    contentContainer: {
        flex: 1, // Prend toute la hauteur disponible
        flexDirection: "column",
        justifyContent: "space-between",
    },
    fieldContainer: {
        width: "100%",
        flexDirection: "column",
        justifyContent: "space-between",
        marginTop: 20,
        gap: 20,
    },
    buttonPlayContainer: {
        alignItems: "center",
        paddingVertical: 20,
    },
    errorText: {
        color: "red",
        fontSize: 16,
        marginBottom: 5,
        textAlign: "left", // Aligne le texte à gauche
    },
});
