import {NavigationProp, RouteProp} from "@react-navigation/native";
import {useQuizService} from "../../../../services/QuizService";
import React, {useEffect, useState} from "react";
import {QuizInformations} from "../../../../models/QuizInformations";
import {Question} from "../../../../models/Question";
import TemplateDuo from "../../../../templates/TemplateDuo";
import HttpError from "../../../../services/HttpError";
import PlayingQuizMultiModeHeader from "./PlayingQuizMultiModeHeader";
import PlayingQuizMultiModeBody from "./PlayingQuizMultiModeBody";
import {Socket} from "socket.io-client";
import {QuestionResponse} from "../../../../models/Response/QuestionResponse";
import {RunInformations} from "../../../../models/RunInformations";


type RoutePropsType = {
    PlayingQuizMultiMode: {
        runId: string;
        socket: Socket;
        roomId: string;
    };
};

interface Props {
    route: RouteProp<RoutePropsType, "PlayingQuizMultiMode">;
    navigation: NavigationProp<any>;
}

export default function PlayingQuizMultiMode({route, navigation}:Props) {
    const {runId, socket, roomId} = route.params;
    const { getQuizInformations, getRunsInfo } = useQuizService();
    const [quizInformations, setQuizInformations] = useState<QuizInformations | undefined>(undefined);
    const [runInformations, setRunInformations] = useState<RunInformations>();
    const [actualQuestion, setActualQuestion] = useState<QuestionResponse | undefined>(undefined);
    const [score, setScore] = useState(0);

    const initSocket = async () => {
        socket.on("gameStarted", (data) => {
            console.log("Game started:", data);
        });

        socket.on("newQuestion", (data) => {
            const question: QuestionResponse = data as QuestionResponse
            setActualQuestion(question);
            // console.log(JSON.stringify(question, null, 2)); // Beautifie le JSON avec 2 espaces d'indentation
        });

    }

    const fetchRuns = async () => {
        if(runId === undefined) return;
        const runFetched = await getRunsInfo(runId);
        if (runFetched instanceof HttpError) {
            console.log("Error fetching runs info", runFetched);
            return;
        }
        const quizInformationsFetched = await getQuizInformations(runFetched.quizId);
        if (quizInformationsFetched instanceof HttpError) {
            console.log("Error fetching quiz info", quizInformationsFetched);
            return;
        }
        setQuizInformations(quizInformationsFetched);
        setRunInformations(runFetched);
    };

    useEffect(() => {
        console.log("PlayingQuizMultiMode starting");
        initSocket();
        fetchRuns();
        setTimeout(() => {
            socket.emit("startGame")
        },500);

        setTimeout(() => {
            socket.emit("nextQuestion");
        },2000);
    }, []);

    return (
        <TemplateDuo
            childrenHeader={<PlayingQuizMultiModeHeader quizInformations={quizInformations} runId={runId} actualQuestion={actualQuestion} score={score}  navigation={navigation}></PlayingQuizMultiModeHeader>}
            childrenBody={<PlayingQuizMultiModeBody runId={runId} actualQuestion={actualQuestion} socket={socket} fetchActualQuestion={()=>{}} roomId={roomId} navigation={navigation}></PlayingQuizMultiModeBody>}
        />
    );
}