import { View, Text, StyleSheet, TouchableOpacity } from "react-native";
import { OnlineSelectModeType } from "../../../models/SelectModeType";

interface Props {
    mode: OnlineSelectModeType;
    setMode: (mode: OnlineSelectModeType) => void;
}

export default function OnlineSelectMode({ mode, setMode }: Props) {
    return (
        <View style={styles.container}>
            <View style={styles.buttonContainer}>
                <TouchableOpacity onPress={() => setMode("create")}>
                    <Text style={[styles.text, mode === "create" && styles.activeText]}>CREATE A LOBBY</Text>
                </TouchableOpacity>
                <View style={[styles.bar, mode === "create" ? styles.activeBar : styles.inactiveBar]} />
            </View>

            <View style={styles.buttonContainer}>
                <TouchableOpacity onPress={() => setMode("join")}>
                    <Text style={[styles.text, mode === "join" && styles.activeText]}>JOIN A ROOM</Text>
                </TouchableOpacity>
                <View style={[styles.bar, mode === "join" ? styles.activeBar : styles.inactiveBar]} />
            </View>

        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        display: 'flex',
        width: '100%',
        height: '12%',
        flexDirection: 'row',
        backgroundColor: '#f3f3f3',
        borderRadius: 10,
        justifyContent: 'space-around',
        alignItems: 'center',
        // Ombre pour Android
        elevation: 5,
        // Ombre pour iOS
        shadowColor: '#000',
        shadowOffset: { width: 0, height: 4 }, // Décalage de l'ombre en bas
        shadowOpacity: 0.25, // Opacité de l'ombre
        shadowRadius: 3.84, // Flou de l'ombre
    },
    buttonContainer: {
        display: 'flex',
        flexDirection: 'column',
        width: '45%',
        alignItems: 'center',
        gap: "2%",
    },
    text: {
        fontSize: 18,
        color: '#bebebe',
        textAlign: 'center',
    },
    activeText: {
        color: '#2ec7ff',
    },
    bar: {
        width: '100%',
        height: '4%',
        marginTop: '4%',
        borderRadius: 10,
    },
    activeBar: {
        backgroundColor: '#2ec7ff', // Couleur pour le bouton actif
    },
    inactiveBar: {
        backgroundColor: '#bebebe', // Couleur grise pour les boutons inactifs
    },
});
