import { View, Image, Text, StyleSheet } from "react-native";
import DefaultButton from "../../../components/buttons/DefaultButton";
import { NavigationProp, RouteProp } from "@react-navigation/native";
import {Quiz} from "../../../models/Quiz";
import {useQuizService} from "../../../services/QuizService";
import HttpError from "../../../services/HttpError";
import {QuizInformations} from "../../../models/QuizInformations";



interface Props {
    navigation: NavigationProp<any>;
    quizInformations: QuizInformations;
    score: number;
}

export default function EndQuizChild({ navigation, quizInformations, score }: Props) {

    const {restartQuiz, remainingQuiz, createRun} = useQuizService()

    const handleRestartPress = async () => {
        const quizId = quizInformations.id.toString();
        const runId = await createRun(quizId);
        navigation.navigate('PlayingQuiz', {runId: runId, quizId: quizId});
    };

    const handleBackToMenu = () => {
        navigation.navigate('TabNavigator');
    };

    return (
        <View style={styles.container}>
            <View style={styles.containerHeader}>
                <Image source={require('../../../assets/TitleApp.png')}/>
            </View>
            <View style={styles.containerBody}>
                <Text style={styles.TextBodyTitle}>{((score/quizInformations.questionCount)*100 > 50 ) ? 'Victory' : 'Defeat'}</Text>
                <Text style={styles.TextBody}>you finish the test with a score of {`${score}/${quizInformations.questionCount}`} ! </Text>
                <Image source={require('../../../assets/uWin.png')} />
                <DefaultButton text="RESTART" handleButtonPressed={handleRestartPress} buttonStyle={styles.whiteButton} buttonText={styles.whiteButtonText}></DefaultButton>
                <DefaultButton text="BACK TO MENU" handleButtonPressed={handleBackToMenu} buttonStyle={styles.blueButton} buttonText={styles.blueButtonText}></DefaultButton>
            </View>
        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        height: '100%',
        width: '100%',
        display: 'flex',
        flexDirection: 'column',
        alignItems: 'center',
        justifyContent: 'space-around'
    },
    containerHeader: {
        height: '10%',
        width: '100%',
        alignItems: 'center',
    },
    containerBody: {
        height: '80%',
        width: '90%',
        display: 'flex',
        flexDirection: 'column',
        alignItems: 'center',
        justifyContent: 'space-around',
        backgroundColor: '#F3F3F3',
        borderRadius: 40,
        padding: '10%',
        shadowColor: "#000",
        shadowOffset: {
            width: 0,
            height: 2,
        },
        shadowOpacity: 0.25,
        shadowRadius: 3.84,

        elevation: 5,
    },
    TextBodyTitle: {
        textAlign: 'center',
        fontSize: 24,
        fontWeight: 'bold',
    },
    TextBody: {
        textAlign: 'center',
        fontSize: 22,
        fontWeight: 'bold',
    },
    whiteButton: {
        height: '12%',
        width: '80%',
        backgroundColor: '#FFFFFF',
        borderColor: '#2B73FE',
        borderWidth: 4,
        borderRadius: 10,
        padding: 0
    },
    whiteButtonText: {
        fontSize: 24,
        fontWeight: 'bold',
        color: '#2B73FE',
    },
    blueButton: {
        height: '12%',
        width: '80%',
        backgroundColor: '#2B73FE',
        borderRadius: 10,
        padding: 0
    },
    blueButtonText: {
        fontSize: 24,
        fontWeight: 'bold',
        color: '#FFFFFF',
    },
});